Catalogs and Tables
===================

.. currentmodule:: daft

.. NOTE::
    Daft's catalog and tables APIs are early in their development.

.. autoclass:: Catalog
    :members:

.. autoclass:: Identifier
    :members:

.. autoclass:: Table
    :members:
